<?php
namespace Teknisa\Model\Geral\Repositories;

class Cliente extends \Doctrine\ORM\EntityRepository {

    public function findAllClientes($limit, $offset)
    {
        $query  = <<<SQL
            SELECT DISTINCT
                   C.CDCLIENTE, C.NRINSJURCLIE, C.NMFANTCLIE, C.IDTPIJURCLIE, OC.CDCLIENTE IDPOSSUI, C.NMRAZSOCCLIE,
                   SLA.ID_CONTROLA_SLA, SLA.ID_PARAM_SLA
              FROM CLIENTE C
         LEFT JOIN (SELECT DISTINCT CDCLIENTE, IDTPOPERCLIE
                      FROM OPERCLIE) OC ON OC.CDCLIENTE = C.CDCLIENTE
         LEFT JOIN SLACLIENTE_PARAM SLA ON C.CDCLIENTE = SLA.CDCLIENTE
             WHERE C.IDCLIEATIV <> 'N'
          ORDER BY C.NMFANTCLIE
SQL;

        if($limit){
            $query  = self::getPaginatedQuery($query, $limit, $offset);
        }
        return $this->getEntityManager()->getConnection()->fetchAll($query);
    }

    public function findClientesPorOperador($cdOperador)
    {
        $query  = <<<SQL
            SELECT OC.CDOPERADOR, OC.CDCLIENTE, C.NRINSJURCLIE, C.NMFANTCLIE,
                   OC.IDTPOPERCLIE, OC.NRPRIOPERCLI, C.IDTPIJURCLIE, OC.IDEMAILENCSO,
                   DECODE(OC.IDTPOPERCLIE, 'R', 'Responsável', 'C', 'Cliente') AS IDTPOPERCLIE
              FROM OPERCLIE OC, CLIENTE C
             WHERE OC.CDOPERADOR = :P_CDOPERADOR
               AND OC.CDCLIENTE = C.CDCLIENTE
          ORDER BY C.NMFANTCLIE
SQL;

        $param = array(
            'P_CDOPERADOR' => $cdOperador
        );
        return $this->getEntityManager()->getConnection()->fetchAll($query, $param);
    }

    public function findRelacionarClientesComOperador($cdoperador){
        $sql = <<<SQL
               SELECT CDCLIENTE, NMFANTCLIE, NMRAZSOCCLIE
                 FROM CLIENTE
                WHERE IDCLIEATIV = 'S'
                  AND CDCLIENTE NOT IN (SELECT OC.CDCLIENTE
                                          FROM OPERCLIE OC, CLIENTE C
                                         WHERE OC.CDOPERADOR = :P_CDOPERADOR
                                           AND OC.CDCLIENTE = C.CDCLIENTE)
             ORDER BY NMFANTCLIE
SQL;
        $param = array(
            'P_CDOPERADOR' => $cdoperador,
        );
        return $this->getEntityManager()->getConnection()->fetchAll($sql, $param);
    }

    public function findParamSla($limit, $offset,$cdcliente){
        $query = <<<SQL
            SELECT CDASSUNTO, CDGRUPFASE, IDPRAZOSLA, QTDIASSLA
              FROM SLACLIENTE
             WHERE CDCLIENTE = :P_CDCLIENTE
SQL;
        if($limit){
            $query  = self::getPaginatedQuery($query, $limit, $offset);
        };
        $param = array(
            'P_CDCLIENTE' => $cdcliente,
        );
        return $this->getEntityManager()->getConnection()->fetchAll($query,$param);
    }

    public static function getPaginatedQuery($query, $limit, $offset) {
        if ($limit > 0) {
            $column = '*';
            if ($offset > 0) {
                $min = $offset + 1;
                $query = 'SELECT * FROM (SELECT a.' . $column . ', rownum AS doctrine_rownum FROM (' .
                    $query .
                    ') a WHERE rownum <= ' . $limit . ') WHERE doctrine_rownum >= ' . $min;
            } else {
                $query = 'SELECT a.' . $column . ' FROM (' . $query . ') a WHERE ROWNUM <= ' . $limit;
            }
        }
        return $query;
    }
}
